==> confluence-create-content-plugin-12.0.5-sources.jar: com/atlassian/confluence/plugins/createcontent/exceptions/RestExceptionMapper.java <==
package com.atlassian.confluence.plugins.createcontent.exceptions;

import com.atlassian.confluence.api.service.exceptions.ReadOnlyException;
import com.atlassian.confluence.plugins.createcontent.api.exceptions.ResourceErrorType;
import com.atlassian.confluence.plugins.createcontent.api.exceptions.RestTypedException;
import com.atlassian.confluence.rest.api.model.ExceptionConverter;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

@Provider
public class RestExceptionMapper implements ExceptionMapper<Exception> {
    @Override
    public Response toResponse(final Exception exception) {
        if (exception instanceof WebApplicationException) {
            return ((WebApplicationException) exception).getResponse();
        }
        if (exception instanceof RestTypedException) {
            RestTypedException restTypedException = (RestTypedException) exception;

            return ResourceException.makeResponse(
                    exception.getMessage(), Response.Status.BAD_REQUEST,
                    restTypedException.getErrorType(), restTypedException.getErrorData()
            );
        }
        if (exception instanceof ReadOnlyException) {
            return ResourceException.makeResponse(exception.getMessage(), ExceptionConverter.AdditionalStatus.READ_ONLY_MODE_ENABLED, ResourceErrorType.ACCESS_MODE, null);
        }
        return ResourceException.makeResponse(exception.getMessage(), Response.Status.INTERNAL_SERVER_ERROR, ResourceErrorType.UNKNOWN, null);
    }
}

==> confluence-create-content-plugin-12.4.1-sources.jar: com/atlassian/confluence/plugins/createcontent/exceptions/RestExceptionMapper.java <==
package com.atlassian.confluence.plugins.createcontent.exceptions;

import com.atlassian.confluence.api.service.exceptions.ReadOnlyException;
import com.atlassian.confluence.plugins.createcontent.api.exceptions.ResourceErrorType;
import com.atlassian.confluence.plugins.createcontent.api.exceptions.RestTypedException;
import com.atlassian.confluence.rest.api.model.ExceptionConverter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

@Provider
public class RestExceptionMapper implements ExceptionMapper<Exception> {
    private final static Logger log = LoggerFactory.getLogger(RestExceptionMapper.class);

    @Override
    public Response toResponse(final Exception exception) {
        if (exception instanceof WebApplicationException) {
            log.error(exception.getMessage(), exception);

            return ((WebApplicationException) exception).getResponse();
        }

        if (exception instanceof RestTypedException) {
            RestTypedException restTypedException = (RestTypedException) exception;

            return ResourceException.makeResponse(
                    exception.getMessage(), Response.Status.BAD_REQUEST,
                    restTypedException.getErrorType(), restTypedException.getErrorData()
            );
        }

        if (exception instanceof ReadOnlyException) {
            return ResourceException.makeResponse(exception.getMessage(), ExceptionConverter.AdditionalStatus.READ_ONLY_MODE_ENABLED, ResourceErrorType.ACCESS_MODE, null);
        }

        log.error(exception.getMessage(), exception);

        return ResourceException.makeResponse(exception.getMessage(), Response.Status.INTERNAL_SERVER_ERROR, ResourceErrorType.UNKNOWN, null);
    }
}
